.. _acquiring_data:

*************************
Acquiring Data with sunpy
*************************

In this section of the guide we will introduce the ways you can obtain different
kind of solar data from different places.

.. toctree::
    :maxdepth: 2

    sample-data
    fido
    jsoc
    hek
    helioviewer
    database
